Python-Blosc2 documentation
============================

Python-Blosc2 is a Python package
that wraps C-Blosc2, the newest version of the Blosc compressor.

.. panels::
    :card: + intro-card text-center
    :column: col-lg-6 col-md-12 col-sm-12 col-xs-12 d-flex

    ---

    Getting Started
    ^^^^^^^^^^^^^^^

    New to Python-Blosc2? Check out the getting started guides. They contain an
    introduction to Python-Blosc2 main concepts and different tutorials.

    +++

    .. link-button:: getting_started/index
            :type: ref
            :text: To the getting started guides
            :classes: btn-info

    ---

    API Reference
    ^^^^^^^^^^^^^

    The reference guide contains a detailed description of the Python-Blosc2 API.
    The reference describes how the functions work and which parameters can
    be used.

    +++

    .. link-button:: reference/index
            :type: ref
            :text: To the reference guide
            :classes: btn-info


    ---

    Development
    ^^^^^^^^^^^

    Saw a typo in the documentation? Want to improve
    existing functionalities? The contributing guidelines will guide
    you through the process of improving Python-Blosc2.

    +++

    .. link-button:: development/index
            :type: ref
            :text: To the development guide
            :classes: btn-info

    ---

    Release Notes
    ^^^^^^^^^^^^^

    Want to see what's new in the latest release? Check out the release notes to find out!

    +++

    .. link-button:: release_notes/index
            :type: ref
            :text: To the release notes
            :classes: btn-info


..  toctree::
    :maxdepth: 1
    :hidden:

    Getting Started <getting_started/index>
    API Reference <reference/index>
    Development <development/index>
    Release Notes <release_notes/index>
